<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#de0f17';
	$primary_bar_color = "#ffffff";

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$header_choices = array(
		'choice-1' => 'Center logo with quotes',
		'choice-2' => 'Left logo with Ad banner'
	);

	$footer_choices = array(
		'choice-1' => 'Light',
		'choice-2' => 'Dark'
	);

	$ad_position_choices = array(
		'1','2', '3','4','5','6','7','8','9','10'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'advanced-magazine-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);

	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Theme Primary Color', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['primary-bar-color'] = array(
		'id' => 'primary-bar-color',
		'label'   => __( 'Primary Nav Bar Color', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_bar_color // hex
	);
	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Roboto Condensed'
	);

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['header-style'] = array(
		'id' => 'header-style',
		'label'   => __( 'Site Header Style', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $header_choices,
		'default' => 'choice-1'
	);

	$options['left-quote-image'] = array(
		'id' => 'left-quote-image',
		'label'   => __( 'Left quote image', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/slogan1.jpg'
	);

	$options['left-quote-header'] = array(
		'id' => 'left-quote-header',
		'label'   => __( 'Left quote header', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Vladimir Putin', 'advanced-magazine-pro'),
	);

	$options['left-quote-text'] = array(
		'id' => 'left-quote-text',
		'label'   => __( 'Left quote text', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => __('I never met with him. We have a lot of Americans who visit us', 'advanced-magazine-pro'),
	);

	$options['right-quote-image'] = array(
		'id' => 'right-quote-image',
		'label'   => __( 'Right quote image', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/slogan2.jpg'
	);

	$options['right-quote-header'] = array(
		'id' => 'right-quote-header',
		'label'   => __( 'Right quote header', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Donald Trump', 'advanced-magazine-pro'),
	);

	$options['right-quote-text'] = array(
		'id' => 'right-quote-text',
		'label'   => __( 'Right quote text', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => __('I think I\'ve made a lot of sacrifices. I work very, very hard', 'advanced-magazine-pro'),
	);

	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['primary-nav-heading'] = array(
		'id' => 'primary-nav-heading',
		'label'   => __( 'Mobile Primary Menu Heading Text', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Categories', 'advanced-magazine-pro'),
	);

	$options['secondary-nav-heading'] = array(
		'id' => 'secondary-nav-heading',
		'label'   => __( 'Mobile Secondary Menu Heading Text', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Pages', 'advanced-magazine-pro'),
	);

	$options['all-posts-url'] = array(
		'id' => 'all-posts-url',
		'label'   => __( 'Page URL to display all latest posts', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/latest',
	);

	$options['archive-excerpt-length'] = array(
		'id' => 'archive-excerpt-length',
		'label'   => __( 'Number of excerpt words (archive)', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '30',
	);

	$options['content-ad-position'] = array(
		'id' => 'content-ad-position',
		'label'   => __( 'Display Content Ad after post:', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $ad_position_choices,
		'default' => '1',
	);

	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Display featured image on single posts', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['footer-style'] = array(
		'id' => 'footer-style',
		'label'   => __( 'Site Footer Style', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $footer_choices,
		'default' => 'choice-1'
	);

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['header-social-on'] = array(
		'id' => 'header-social-on',
		'label'   => __( 'Display social icons on site header', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['facebook-url'] = array(
		'id' => 'facebook-url',
		'label'   => __( 'Your Facebook URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['twitter-url'] = array(
		'id' => 'twitter-url',
		'label'   => __( 'Your Twitter URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['youtube-url'] = array(
		'id' => 'youtube-url',
		'label'   => __( 'Your YouTube URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['linkedin-url'] = array(
		'id' => 'linkedin-url',
		'label'   => __( 'Your LinkedIn URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['pinterest-url'] = array(
		'id' => 'pinterest-url',
		'label'   => __( 'Your Pinterest URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['rss-url'] = array(
		'id' => 'rss-url',
		'label'   => __( 'Your RSS feed URL', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',
	);

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'advanced-magazine-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);
	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'advanced-magazine-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );
